#
# spec file for package pan
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pan
Version:        0.155
Release:        1.2
Summary:        A Newsreader for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Networking/News/Clients
URL:            http://pan.rebelbase.com/
Source0:        https://gitlab.gnome.org/GNOME/pan/-/archive/v%{version}/%{name}-v%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext >= 0.21
BuildRequires:  itstool
BuildRequires:  libtool
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(gcr-3)
BuildRequires:  pkgconfig(gmime-3.0)
BuildRequires:  pkgconfig(gnutls) >= 3.0.0
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtkspell3-3.0) >= 2.0.16
BuildRequires:  pkgconfig(libnotify) >= 0.4.1
BuildRequires:  pkgconfig(libsecret-1)

%description
Pan is a Usenet newsreader that's good at both text and binaries.
It supports offline reading, scoring and killfiles, yEnc, NZB, PGP
handling, multiple servers, and secure connections.

%lang_package

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
	--with-gnutls \
	--with-dbus \
	--enable-gkr \
	--enable-manual \
	--enable-libnotify \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_prefix}

%files
%license COPYING COPYING-DOCS
%doc AUTHORS NEWS README.org
%doc %{_datadir}/help/C/%{name}/
%{_mandir}/man?/pan.?%{ext_man}
%{_bindir}/%{name}
%{_datadir}/applications/*.%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/*.%{name}.png
%{_datadir}/metainfo/*.%{name}.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sun Nov 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.155:
  * Add libiconv link if needed to fix build on MacOS
  * Use password storage by default when it is enabled
  * Enable back GPG initialization
  * Fix crash in on_socket_created() when password storage is enabled
  * score rules: makes : and :: behave as specified in slrn manual
- Drop patches for issues fixed upstream:
  * 0001-Fix-crash-in-on_socket_created-when-password-storage.patch
* Thu Jan 26 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to fix crash when password storage is enabled
  * 0001-Fix-crash-in-on_socket_created-when-password-storage.patch
* Wed Jan 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.154:
  * Fix a regression from v0.153 where pan can segfault when
    reading groups (glgo#GNOME/pan#156).
  * A few GTK2 related cleanups.
* Sun Nov 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.153:
  * Identify as correct version.
- Changes from version 0.152:
  * Gtk2 was removed from Pan. Only Gtk3 is working.
  * Links to old pan.rebelbase.com are replaced with links to
    pan gitlab page.
  * Pan can be compiled with clang.
  * Updated translations.
* Mon Jul  4 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.151
  * Gtk2 minimal version is now 2.24.0.
  * Fix header handling errors (fixes glgo#GNOME/pan#61 and
    glgo#GNOME/pan#66).
  * Add a menu entry to allow editing the Score file in text
    editor (fixes glgo#GNOME/pan#11).
* Fri Mar 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(enchant) for pkgconfig(enchant-2)
  BuildRequires: Use the newer enchant-2 spellchecker.
* Wed Mar  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pan-lang Recommends: No longer needed.
* Sun Feb 27 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.150:
  * Set maximum number of serveur connections to 20.
  * Remove support for GMime2.
  * Enable make distcheck for both GTK builds.
  * Run distcheck with gtk3.
  * Fix make distcheck for gtk2.
  * Gtk3 is now default build, Gtk2 is deprecated.
  * Fix pkg check msgs in configure.ac and print more library versions.
  * fix missing articles with dangling reference.
* Fri Dec 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.149:
  * Fix freeze when loading group with non-ascii characters in
    subject.
  * Avoid mojibake in Subject and Headers.
  * Fix x-face folding.
  * Add Base64-encoded Face header.
  * Updated translations.
* Tue Oct 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.148:
  + gmime3 is used by default and gmime2 is deprecated.
  + Some UI bugs fixed.
  + README was converted from ASCII to org-mode format.
- Adapt Source and setup for changed version tagging (v0.148 vs
  0.148).
- New BuildRequires: libtool (needed to generate missing configure
  file in release tarball), yelp (needed to build help files).
* Tue Sep 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.147:
  + Fix for GMime3 bug in: message_add_signed_part().
  + Try an autodetection strategy.
  + Fix compiler warning.
  + Work around corrupt/inconsistent file names.
  + Replace totally unnecessary UTF-8 colons by real ones.
  + Remove empty line from file posting.xml.
  + Fix for GMime3 build (Posting error); Issues
    glgo#GNOME/pan#103 and glgo#GNOME/pan#114.
  + build: Target a specific GLib API version.
  + fix (configure.ac): update GETTEXT version.
  + Adjust packages to install in CI.
  + Move more header inclusions outside extern "C".
  + Take <glib.h> out of extern "C".
  + Updated translations.
- Drop patches either included upstream or otherwise fixed:
  + pan-fix-sending-with-gmime30.patch
  + pan-glib-2.68.patch
  + pan-signed-pointer-zero-comparison.patch
- Update minimum required version of gettext to 0.21 in keeping
  with upstream.
* Tue Jun  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add pan-signed-pointer-zero-comparison.patch -- Fix comparison
  of pointer with int 0 (fixes building against GCC 11).
* Sat May  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add pan-glib-2.68.patch: Fix compilation with glib 2.68+; patch
  taken from upstream merge request with additional fixes for
  current version (glgo#GNOME/pan#128).
* Sun Jul  5 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add pan-fix-sending-with-gmime30.patch: Fix message sending when
  using gmime 3.0 (boo#1166404,
  https://gitlab.gnome.org/GNOME/pan/-/issues/103,
  https://gitlab.gnome.org/GNOME/pan/-/issues/114).
* Thu Nov 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.146:
  + Use an int instead of a char.
  + Fix segfault when build with gmime-3.
  + Fix to build Pan with options --with-gmime30 and
  - -with-gmime-crypto.
  + Fix ypart begin for bpf ranges.
  + Updated translations.
- Replace pkgconfig(gmime-2.6) with pkgconfig(gmime-3.0) and pass
  - -with-gmime30 to configure.
* Thu May 31 2018 badshah400@gmail.com
- Update to version 0.145:
  + Do not use front() on empty vector.
  + Bug 793228 nzb file with empty segment lists crash pan.
  + Bug 793277 Use after free in main().
  + Updated translations.
- Drop patches incorporated upstream:
  + pan-fix-empty-nzb-crash.patch.
  + pan-do-not-use-front-on-empty-vector.patch.
  + pan-fix-use-after-free-in-main.patch.
* Fri May  4 2018 bjorn.lie@gmail.com
- Add upstream bug fix patches:
  + pan-fix-use-after-free-in-main.patch: Use after free in main()
    (bgo#793277).
  + pan-fix-empty-nzb-crash.patch: nzb file with empty segment
    lists crash pan (bgo#793228).
  + pan-do-not-use-front-on-empty-vector.patch: Do not use front()
    on empty vector.
* Thu Feb  8 2018 okurz@suse.com
- Adapt license file location according to new suggestion around
  %%%%license
* Mon Jan 15 2018 zaitor@opensuse.org
- Update to version 0.144:
  * Validate pan.appdata.xml.in and tweak cleanfiles.
  * Remove outdated FSF address.
  * Update README.
  * Add man page.
  * Upgrade pan.appdata.xml.in.
  * Require GMime 3.0 to be explicitly enabled, don't fallback to
    it (bgo#791435).
  * Patch for GMime 3.0. Porting to GMime 3.0 still not completed
    (bgo#786438).
  * Can't open nzb files from desktop (bgo#789988).
  * Follow Icon Theme Specification.
  * Updated translations.
- Drop update-desktop-files BuildRequires and stop using
  suse_update_desktop_file macro and drop post(un) handling of
  desktop_database_post, no longer needed.
- Use autosetup and make_build macros, modernize spec.
- Update description.
* Tue Dec 26 2017 jengelh@inai.de
- Remove filler wording from description.
- Avoid running fdupes across partition boundaries.
* Fri Dec 22 2017 asterios.dramis@gmail.com
- Update to version 0.143:
  * Use xdg-open instead of deprecated gnome-open.
  * Fix nits wrt GMime 3.0.
  * First patch to enable GMime 3.0 lib. Porting to GMime 3.0 not
    yet completed.
  * One more Unicode apostrophe.
  * Edit strings.
  * Added autohiding attachments panel.
  * Fixed groups/body panels resizing in GTK 3.
  * Attempt to fix display of threads with unread articles.
  * Use Unicode in translatable strings.
  * Fixed showing combobox options unlocalized.
  * Enable all TLS versions supported by GnuTLS.
  * Updated translations.
* Fri Jul 28 2017 zaitor@opensuse.org
- Update to version 0.142:
  * Update docs for password storage change.
  * Fix some ISO C++ 11 warnings.
  * Change use-gnome-keyring to use-password-storage.
  * Build libsecret & gcr with gtk3 only, gnome-keyring with gtk2.
  * Remove dependency on deprecated libgnome-keyring. New libraries
    used: libsecret and gcr (GTK+ 3 only).
  * Rewrite autogen.sh to drop dependency on gnome-common.
  * Nuke intltool.
  * Forgot to update HELP_LINGUAS.
  * Fix the strftime test for mingw64.
  * Update docs and include COPYING-DOCS.
  * Re-add help menu item for manual.
  * Add new documentation infrastructure.
  * Fixed typos in a string.
  * Improve help.
  * Final fixes to the help system.
  * Tweak the help support.
  * Add gnome-doc-utils basic support.
  * Add Pan manual.
  * Fix size of preference window too large (bgo#697983).
  * Fix Header Pane menu not shown when built without option
  - -with-gnutls (bgo#777711).
  * Mention crypto in configure output.
  * Updated translations.
- Drop old conditionals for gtk2 and obsolete versions of openSUSE.
- Following the above and upstream changes, drop the following
  BuildRequires: intltool, translation-update-upstream,
  pkgconfig(gmime-2.4), pkgconfig(gnome-keyring-1),
  pkgconfig(gtk+-2.0) and pkgconfig(gtkspell-2.0).
- Following upstream changes, add new BuildRequires: gettext,
  libxml2-tools, itstool pkgconfig(libsecret-1) and
  pkgconfig(gcr-3).
- Pass --enable-manual to configure, build the new manual.
* Sat Mar  4 2017 asterios.dramis@gmail.com
- Update to version 0.141:
  * Treat a 500 response to MODE READER as OK.
  * Fix various memory leaks.
  * Fix for clang static analyzer.
  * Fix for cannot start after removing last news server.
  * Do not overwrite silently draft file (bgo#704227).
  * Get rid of deprecated g_atexit() calls.
  * Fix for closing Pan without server config (bgo#729329).
  * Deprecated g_type_init() with glib2 > 2.36.
  * Updated translations.
* Mon May 30 2016 badshah400@gmail.com
- Switch to building with gtk3: bnc#728311 and bgo#669403 seem to
  be solved for the combination of recent gtk3 and current version
  of pan.
* Mon May 30 2016 badshah400@gmail.com
- Update to version 0.140:
  + Long list of changes, see entries under v0.140 at
    https://git.gnome.org/browse/pan2/plain/NEWS.
- Drop fix-desktop-file-11.0.diff; incorporated upstream. Also
  drop gnome-patch-translation BuildRequires and all patch0 related
  commands.
- No longer add News and Network categories to desktop file by
  invoking suse_update_desktop_file; already added to upstream
  desktop file.
- Package appdata file.
- Upstream dropped CHANGELOG file and replaced it with NEWS.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Jul 23 2012 zaitor@opensuse.org
- Update to version 0.139:
  + std::logic_error thrown ("basic_string::_S_construct null not
    valid") (bgo#678445)
  + Added error popup for posting to a disabled server.
  + Patches to SSL socket handling.
  + Clear last-visited (group/article) on middle-click.
  + Updated translations.
- Changes from version 0.138:
  + Hotkey for showing/hiding signatures in the article body.
    (bgo#350496)
  + Keep position on selected item on re-order. (bgo#443702)
  + Remember last read post. (bgo#448416)
  + Open url in browser. (bgo#464335)
  + Signature printed double when line needs to be wrapped.
    (bgo#533178)
  + Tasks marked "Stopped" should also remain stopped when pan is
    restarted. (bgo#543319)
  + "Save at" options other then %%g and %%G. (bgo#550007)
  + Filter Cross-posters. (bgo#587585)
  + pan 136 using secure ssl and get continuous popups for certs
    but no  connection. (bgo#673927)
  + PO message very difficult to translate. (bgo#675953)
  + Pan crashes while fetching new headers. (bgo#677741)
  + Updated translations.
- Changes from version 0.137:
  + Bugfix release for errors regarding segfaults etc. with thread
    handling.
  + Colorize group names.
  + Fix three-horizontal-pane layout between sessions.
  + Stop tasks when there is no space left on device.
  + Honour default attachments folder setting if group folder is
    not set.
  + Updated translations.
- Drop pan-fix-warnings.patch and pan-gtkspell3.patch, fixed
  upstream.
- Remove ref to (bgo#669403) fixed upstream.
- Added upstream bugref to patchtag (bgo#680468).
- Pass --enable-gkr to configure, it's set to auto-off if not.
- Pass --enable-libnotify to configure, it's set to off if not.
- Pass --with-dbus to configure, it's set to off if not.
* Wed Apr 11 2012 zaitor@opensuse.org
- Add pan-gtkspell3.patch: Make configure look for the right
  pkgconfig name for gtkspell3.
* Tue Apr 10 2012 vuntz@opensuse.org
- Update to version 0.136:
  + Support for uploading attachments (with NZB creation) to
    Usenet.
  + Selectable Content-Transfer-Encoding.
  + Selectable GtkSpell default language.
  + Support for encrypting and signing articles with a
    public/private PGP key.
  + Connections can now be encrypted with TLS 1.0.
  + Various bugfixes/enhancements from Bugzilla.
  + Auto-Cache/-Download/-Delete/-Mark read based on scores.
  + D-Bus support for automatic batch addition of new files to the
    Download Queue.
  + Status Icon support.
  + GNOME Keyring support for safely storing server passwords.
  + Updated translations.
- Rebase fix-desktop-file-11.0.diff, and stop updating pan.desktop
  there: instead remove pan.desktop in %%prep, so it will get
  rebuilt.
- Drop pan-glib-2.31.patch: fixed upstream.
- Add pan-fix-warnings.patch: fix some gcc warnings breaking the
  build.
- Add pkgconfig(enchant) BuildRequires to keep building spelling
  support.
- Add pkgconfig(gnome-keyring-1) BuildRequires on 12.1 and later to
  enable password storage.
- Add pkgconfig(gnutls) BuildRequires and pass --with-gnutls to
  configure for TLS support.
- Add pkgconfig(libnotify) BuildRequires for notifications support.
* Tue Jan 31 2012 zaitor@opensuse.org
- Rebuilt package against GTK2, instead of GTK3 (for now).
  + No spell-check in Pan. bnc#725971
  + Pan groups panel re-sizes itself and gets stuck in new
    position. bnc#728311
  + Corrected erroneous sourceurl in specfile.
* Thu Jan 12 2012 dimstar@opensuse.org
- Build openSUSE > 12.1 against gmime 2.6: Conditionally change
  pkgconfig(gmime-2.4) BuildRequires to pkgconfig(gmime-2.6).
* Thu Dec  1 2011 dimstar@opensuse.org
- Add pan-glib-2.31.patch: Fix build with glib 2.31.
* Fri Oct 14 2011 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Mon Jun 27 2011 vuntz@opensuse.org
- Update to version 0.135:
  + Improve URI detection in the body pane.
  + Make highlighting of URIs in the body pane optional.
  + Add a newsrc autosave timer.
  + Fix mailto URI encoding. (bgo#648375)
  + Create a NZB file from the list of articles.
  + Optional compatibility with GTK+ 3.
  + Fix the text-massager-test failure. (bgo#642746)
  + Support format=flowed in text-massager.
  + Guess deliberate line breaks.
  + Saving articles from the NZB file no longer causes articles to
    be queued multiple times.
  + Separate line length check for each quote level. Should only be
    for quoted levels.
  + Add the wrap selected option to the post editor.
  + Slightly improve Pan.ico. (bgo#499214)
  + Updated translations.
- Drop pan-0.134-handle-nzb-multipart.patch: fixed upstream.
- Use favor_gtk2 to switch between gtk2 and gtk3 builds. Changes
  for gtk3 build:
  + use pkgconfig(gtk+-3.0) instead of pkgconfig(gtk+-2.0), and do
    not use pkgconfig(gtkspell-2.0) as gtkspell requires gtk2.
  + pass --with-gtk3 to configure.
- Drop call to autoreconf, which is not needed by anything.
* Mon May 30 2011 sbrabec@suse.cz
- Merged changes from Daniel Rahn and openSUSE:Factory.
* Mon May 30 2011 daniel.rahn@novell.com
- Add pan-0.134-handle-nzb-multipart.patch: fix nzb handling of
  multipart messages, bnc#685759.
* Sun Feb 20 2011 vuntz@opensuse.org
- Update to version 0.134:
  + No window icon when running in NZB-mode. (bgo#574419)
  + Use GRegex instead of PCRE. (bgo#596653)
  + Tooltips missing from two 'Post Article' toolbar buttons.
    (bgo#548860)
  + Infinite loop with server that doesn't support LIST NEWSGROUPS.
    (bgo#545220)
  + Add port to server dialog. (bgo#527313)
  + Support 64 bit article numbers. (bgo#549655)
  + Don't queue xover for 0 connections. (bgo#596682)
  + Make wrapping honor changes in compose-wrap pref. (bgo#596680)
  + Change nzb task saving delay & add pref. (bgo#596683)
  + Port to GMime 2.4 & 2.5. (bgo#541676, bnc#683008)
  + Spawn editor asynchronously. (bgo#465763)
  + Change allocation buffer for article tree.
  + Save some more memory by re-ordering a few variables.
  + Don't save files as executable.
  + Fix handling of multibyte spaces in text-massager.
  + Re-write multipart handling for viewing.
  + Change default mime-type for incoming attachments. (bgo#135734)
  + Add some additional mime types.
  + Fix bug in multipart article mids.
  + Add console support for windows.
  + Update filter-info and scorefile-test to support non-overview
    headers.
  + Skip non-overview test if not cached.
  + Allow scoring article on all headers.
  + Promote rescore_articles to data interface.
  + Update score when article is cached.
  + Add regex support to search. (bgo#351196)
  + Additional info for about & User-Agent. (bgo#424083)
  + Allow subject line use in save path. (bgo#403797)
  + Improve regexes used for squashing subject line.
  + Reduce memory allocation for multiparts.
  + Allow newsrc paths relative to PAN_HOME.
  + Save tasks on exit. (bgo#609355)
  + Always show full revision info in UA hdr.
  + Remember size of post window.
  + Add tests for subject line.
  + Make separator user configurable.
  + Add support for Face header.
  + Fix various crashes.
  + Stop using deprecated API and behaviors (including bgo#579753,
    bgo#596648).
  + Build fixes (including bgo#573722).
  + Updated translations.
- Update fix-desktop-file-11.0.diff to apply without fuzz.
- Drop pan-0.133-gcc44.patch: fixed upstream.
- Drop pan-gmime24.patch: fixed upstream.
- Remove pcre-devel BuildRequires as pan now uses GRegex.
- Remove xf86tools Requires: this is now provided by x11-tools, and
  there is nothing useful for pan there.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Sun Aug 22 2010 dimstar@opensuse.org
- Switch to gmime 2.4:
  + Change gmime-devel BuildRequires to pkgconfig(gmime-2.4).
  + Add pan-gmime24.patch in order to be able to build against gmime
    2.4; taken from http://github.com/lostcoder/pan2/commit/eb4a0e36
  + Call autoreconf, as pan-gmime24.patch touches configure.in.
- Change gtk2-devel BuildRequires to pkgconfig(gtk+-2.0) and
  gtkspell-devel to pkgconfig(gtkspell-2.0).
- Clean spec file using spec-cleaner.
- Tag patches.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Feb 27 2009 crrodriguez@suse.de
- fix build with GCC 4.4
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Feb 12 2009 drahn@suse.de
- update to stable release 0.133
- obsoletes patches for CVE-2008-2363, glib-compat and gcc 4.3
- remove esound-devel from BuildRequires
* Wed Feb 11 2009 ro@suse.de
- use sr@latin instead of sr@Latn
* Fri May 30 2008 drahn@suse.de
- fix for heap overflow (bnc#395452)
  CVE-2008-2363
* Mon Apr  7 2008 drahn@suse.de
- add glib compat layer to abstract glib API
  obsoletes previous g_assert centric patch
* Fri Feb 29 2008 ro@suse.de
- fix include file to get g_assert
* Fri Dec 14 2007 drahn@suse.de
- pan-gcc-4.3.diff - fix compilation with GCC 4.3
- fix-desktop-file-11.0.diff - fix desktop file for >10.3
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Sun Aug  5 2007 drahn@suse.de
- update to version 0.132 (sync with BS) "Waxed in Black"
- fix some crashes and lockups
* Fri Jan 12 2007 sbrabec@suse.cz
- Spec file cleanup.
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Sun Nov 19 2006 drahn@suse.de
- update to release 0.119 (sync with BS)
  - 0.119 "Karma Hunters"
  - 0.118 "Gustaf Von Musterhausen"
  - 0.117 "We'll fly and we'll fall and we'll burn"
  - multiple bugfixes and performance improvements
* Sat Nov 18 2006 stbinner@suse.de
- Fix Name entry of .desktop file post openSUSE 10.2
* Tue Sep 12 2006 drahn@suse.de
- update to release 0.112
  - 0.112 "FIXME"
  - 0.111 "Tweedy"
  - 0.110 "Beable Beable"
  - countless bugfixes in all areas
* Thu Sep  7 2006 aj@suse.de
- Build with RPM_OPT_FLAGS.
- Build against gtkspell.
* Tue Sep  5 2006 aj@suse.de
- Further cleanup of BuildRequires.
* Mon Sep  4 2006 ro@suse.de
- first step to cleanup BuildRequires
* Tue Aug 22 2006 drahn@suse.de
- update to beta 0.109
* Mon May 29 2006 drahn@suse.de
- update to beta 0.99
* Wed May  3 2006 drahn@suse.de
- update to beta 0.95
* Sun Apr 23 2006 drahn@suse.de
- update to beta 0.94
* Thu Apr 20 2006 drahn@suse.de
- update to beta release 0.93
- enable spell check
- temporarily remove preferences patch
* Fri Feb 17 2006 gekker@suse.de
- Update desktop file for UI team
* Wed Feb 15 2006 stbinner@suse.de
- fix Name/GenericName in .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Oct 14 2005 ro@suse.de
- removed libzvt from neededforbuild (unused)
* Tue Jun 28 2005 sbrabec@suse.cz
- Call desktop-launch to get default browser (#9006).
* Sun May  1 2005 mmj@suse.de
- Fix for gcc4
- Enable parallel build
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Wed Mar 16 2005 clahey@suse.de
- Move desktop file so that it'll be found.
* Wed Nov 10 2004 ro@suse.de
- removed gnome1 stuff from neededforbuild
* Wed Oct 27 2004 mmj@suse.de
- Rename locale no to nb
* Tue May 11 2004 clahey@suse.de
- Added patch to use gnome-open.
* Fri Feb 20 2004 sbrabec@suse.cz
- Fixed names of GNOME2 packages.
* Wed Jan 28 2004 drahn@suse.de
- update to 0.14.2
- set default editor to gedit
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated neededforbuild (rename of librsvg2, eel2).
* Fri Aug 15 2003 adrian@suse.de
- add Categories
* Mon Jul 14 2003 drahn@suse.de
- finally renamed package to PAN
- changed PREFIX to /opt/gnome
- use %%find_lang
* Mon Jun 16 2003 drahn@suse.de
- add patch for PAN incorrectly handling sockets
* Mon May 12 2003 drahn@suse.de
- update to new stable version 0.14.0
- cleanup of #neededforbuild and #usedforbuild
* Wed Jan 15 2003 drahn@suse.de
- update to new stable version 0.13.3
- bugfixes:
  * Fixed a serious 0.13.1 memory leak, and 0.13.2.92 cache
    overflow, caused by the Task Manager window.
  * Fixed a race condition that could cause Pan to crash on startup
    when the ``restore tasks?'' dialog appeared.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xf86 xdevel> to <x-devel-packages>
* Sat Nov  9 2002 drahn@suse.de
- update to new stable version 0.13.2
- bugfixes:
  * Fix 0.13.1 bug that crashed Pan when it encountered user-defined
    filters whose names included underscores.
  * Fix large 0.13.1 memory leak in the Task Manager.
* Mon Oct 14 2002 drahn@suse.de
- update to new stable version 0.13.1
- bugfixes:
  * Posted messages from 0.13.0 lacked the proper encoding header.
  * Fix 0.13.0 crash caused by forwarding email.
  * Fixed 0.13.0 message corruption fix in the composer when a
    signature contains 8bit characters.
  * Don't save the attachment when the user presses the escape key.
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug 23 2002 drahn@suse.de
- fixed broken desktop file (#18219)
* Mon Aug 19 2002 drahn@suse.de
- fixed wrong declarations in gmime-message-part.c
* Mon Aug 19 2002 drahn@suse.de
- update to new stable version 0.13.0
- fixed several bugs:
  * About a dozen minor memory leaks fixed
  * Fixed 0.12.0 bug where the external editor used when
  comparing a message had to use UTF-8
  * Fixed 0.12.0 bug that caused Pan to crash on mouseover
  of some URLs.
* Tue Jul 23 2002 drahn@suse.de
- Update to new stable release 0.12.1
- Fixed various bugs that would cause gnpan to loose articles
* Thu Jun 27 2002 schwab@suse.de
- Fix conflicting declarations.
* Thu Jun 27 2002 drahn@suse.de
- adjusted build process for GNOME 2.0
- fixed desktop-file for menu generation
* Fri Jun 21 2002 drahn@suse.de
- cleanup directories to fit GNOME 2.0 layout
* Thu Jun 20 2002 drahn@suse.de
- switched to stable version 0.12.0 for GNOME 2.0
- fixed some memory leaks and improved i18n
- fixed decoding of quoted-printable headers
* Wed Apr 24 2002 drahn@suse.de
- update to stable version 0.11.3
    Bug fixes:
  * Fixed bug that caused multi-part binary posts with subjects like
    (3/28) instead of (03/28) to be seen as incomplete. Thanks to Craig
    Orsinger for reporting this.
  * Fixed various memory leaks.
* Fri Feb  8 2002 drahn@suse.de
- update to stable version 0.11.2
* Sat Feb  2 2002 drahn@suse.de
- update to version 0.11.1.94
    Bug fixes:
  * Fixed 0.10.0.93 bug that caused a GUI lockup under arcane
    circumstances when reading articles.
  * Fixed 0.11.1.92 bug that caused Pan to crash when emptying
    a group which had an article displayed in the text pane.
  * Fixed 0.11.1.92 bug that caused a GUI lockup under other
    arcane circumstances.
  * Fixed 0.11.1.92 bug that caused the first article read to
    not be displayed if the user started up Pan in zoom mode.
  * Fixed several other 0.11.1.93 deadlock issues.
  * Now handles '~' in the TMPDIR environmental variable.
* Thu Jan 31 2002 drahn@suse.de
- update to version 0.11.1.93
    Bug fixes:
  * Fixed 0.11.1.92 bug that caused cached articles to not be
    marked as read when the user read them.
  * Fixed 0.11.1.92 bug that made the "Edit Filter" dialog too
    wide to fit even on large screens.
  * Fixed 0.10.0 bug where new articles that automatically get
    deleted by user-defined rules could still appear in the
    article pane.
  * Fixed a long-standing NNTP server connection corruption bug.
  * Fixed a couple of long-standing GUI thread bugs.
* Wed Jan 23 2002 drahn@suse.de
- update to version 0.11.1.92
    Bug fixes:
  * Fixed 0.11.1.90 bug that caused Pan to crash sometimes
    when reading or decoding articles.
  * Fixed 0.11.1.90 bug that caused pan to crash on a SIGPIPE
    signal when a news server connection closed unexpectedly.
  * Fixed 0.11.1.90 bug that caused Pan to not authenticate
    properly on at least one older NNTP server.
  * Fixed 0.10.0.93 memory leak that didn't free all article
    information on duplicate or user-deleted articles.
* Wed Jan  9 2002 drahn@suse.de
- update to version 0.11.1.90
    Features:
  * Support for Microsoft Secure Password Authentication ("SPA")
  * more translations
    Bug fixes:
  * fixed a huge memory leak
  * fixed thread safety bugs
  * fixed "Get New Headers" command
* Tue Dec 11 2001 hhetter@suse.de
- updated to stable version 0.11.1
  Featuring:
  * The left/right arrow keys now collapse/expand the
  currently-selected threads
  * Added 'Newsreader' to the 'Headers to Show' selection
  in the preferences
  * New Simplified Chinese translation
  * New Portuguese translation
  Bug fixes:
  * Fixed "supercede article" bug
  * Small task manager bug fixes
- setup -n pan  to build in directory pan instead of gnpan
- functionality test on i386
* Fri Nov 30 2001 drahn@suse.de
- update to version 0.11.0.92
- fixed several bugs that could cause gnpan to crash
* Tue Nov 13 2001 drahn@suse.de
- fixed SPEC file to build on (hopefully) all architectures
* Fri Nov  9 2001 drahn@suse.de
- first SuSE package - version 0.11.0
- renamed package and binary to gnpan because of conflicts with different
  package
